==> goredo-1.4.0.tar.zst: goredo-1.4.0/src/log.go <==
/*
goredo -- djb's redo implementation on pure Go
Copyright (C) 2020-2021 Sergey Matveev <stargrave@stargrave.org>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, version 3 of the License.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

// Logging facilities

package main

import (
	"bytes"
	"flag"
	"fmt"
	"os"
	"strings"
	"sync"

	"golang.org/x/term"
)

const (
	EnvLevel      = "REDO_LEVEL"
	EnvNoProgress = "REDO_NO_PROGRESS"
	EnvDebug      = "REDO_DEBUG"
	EnvLogWait    = "REDO_LOG_WAIT"
	EnvLogLock    = "REDO_LOG_LOCK"
	EnvLogPid     = "REDO_LOG_PID"
	EnvLogJS      = "REDO_LOG_JS"
	EnvNoColor    = "NO_COLOR"
)

var (
	Level      = 0
	NoColor    bool
	NoProgress bool
	Debug      bool
	LogWait    bool
	LogLock    bool
	LogJS      bool
	MyPid      int

	CDebug string
	CRedo  string
	CWait  string
	CLock  string
	CErr   string
	CWarn  string
	CJS    string
	CReset string
	CNone  string = "NONE"

	flagNoProgress = flag.Bool("no-progress", false, fmt.Sprintf("no progress printing (%s=1), also implies -no-status", EnvNoProgress))
	flagDebug      = flag.Bool("d", false, fmt.Sprintf("enable debug logging (%s=1)", EnvDebug))
	flagLogWait    = flag.Bool("log-wait", false, fmt.Sprintf("enable wait messages logging (%s=1)", EnvLogWait))
	flagLogLock    = flag.Bool("log-lock", false, fmt.Sprintf("enable lock messages logging (%s=1)", EnvLogLock))
	flagLogPid     = flag.Bool("log-pid", false, fmt.Sprintf("append PIDs (%s=1)", EnvLogPid))
	flagLogJS      = flag.Bool("log-js", false, fmt.Sprintf("enable jobserver messages logging (%s=1)", EnvLogJS))

	LogMutex     sync.Mutex
	KeyEraseLine string
	LogWasStatus bool
)

func init() {
	var b bytes.Buffer
	t := term.NewTerminal(&b, "")
	CDebug = string(t.Escape.Yellow)
	CRedo = string(t.Escape.Green)
	CWait = string(t.Escape.Blue)
	CLock = string(t.Escape.Cyan)
	CErr = string(t.Escape.Red)
	CWarn = string(t.Escape.Magenta)
	CJS = string(t.Escape.White)
	CReset = string(t.Escape.Reset)
	KeyEraseLine = fmt.Sprintf("%s[K", CReset[0:1])
}

func erasedStatus(s, end string) string {
	if LogWasStatus {
		s += KeyEraseLine
	}
	return s + end
}

func trace(level, format string, args ...interface{}) {
	var p string
	if MyPid != 0 {
		p = fmt.Sprintf("[%d] ", MyPid)
	}
	switch level {
	case CNone:
		p = StderrPrefix + p + fmt.Sprintf(format, args...)
		LogMutex.Lock()
		os.Stderr.WriteString(erasedStatus(p, "\n"))
		LogWasStatus = false
		LogMutex.Unlock()
		return
	case CDebug:
		if !Debug {
			return
		}
		p += "dbg  "
	case CWait:
		if !(LogWait || Debug) {
			return
		}
		p += "wait "
	case CRedo:
		if NoProgress {
			return
		}
		p += "redo "
	case CLock:
		if !(LogLock || Debug) {
			return
		}
		p += "lock "
	case CJS:
		if !(LogJS || Debug) {
			return
		}
		p += "js   "
	case CErr:
		p += "err  "
	case CWarn:
		p += "warn "
	}
	msg := fmt.Sprintf(format, args...)
	msg = StderrPrefix + colourize(level, p+strings.Repeat(". ", Level)+msg)
	LogMutex.Lock()
	os.Stderr.WriteString(erasedStatus(msg, "\n"))
	LogWasStatus = false
	LogMutex.Unlock()
}

func colourize(colour, s string) string {
	if NoColor {
		return s
	}
	return colour + s + CReset
}

==> goredo-1.6.0.tar.zst: goredo-1.6.0/src/log.go <==
/*
goredo -- djb's redo implementation on pure Go
Copyright (C) 2020-2021 Sergey Matveev <stargrave@stargrave.org>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, version 3 of the License.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

// Logging facilities

package main

import (
	"bytes"
	"flag"
	"fmt"
	"os"
	"strings"
	"sync"

	"golang.org/x/term"
)

const (
	EnvLevel      = "REDO_LEVEL"
	EnvNoProgress = "REDO_NO_PROGRESS"
	EnvDebug      = "REDO_DEBUG"
	EnvLogWait    = "REDO_LOG_WAIT"
	EnvLogLock    = "REDO_LOG_LOCK"
	EnvLogPid     = "REDO_LOG_PID"
	EnvLogJS      = "REDO_LOG_JS"
	EnvNoColor    = "NO_COLOR"
)

var (
	Level      = 0
	NoColor    bool
	NoProgress bool
	Debug      bool
	LogWait    bool
	LogLock    bool
	LogJS      bool
	MyPid      int

	CDebug string
	CRedo  string
	CWait  string
	CLock  string
	CErr   string
	CWarn  string
	CJS    string
	CReset string
	CNone  string = "NONE"

	flagNoProgress = flag.Bool("no-progress", false, fmt.Sprintf("no progress printing (%s=1), also implies -no-status", EnvNoProgress))
	flagDebug      = flag.Bool("d", false, fmt.Sprintf("enable debug logging (%s=1)", EnvDebug))
	flagLogWait    = flag.Bool("log-wait", false, fmt.Sprintf("enable wait messages logging (%s=1)", EnvLogWait))
	flagLogLock    = flag.Bool("log-lock", false, fmt.Sprintf("enable lock messages logging (%s=1)", EnvLogLock))
	flagLogPid     = flag.Bool("log-pid", false, fmt.Sprintf("append PIDs (%s=1)", EnvLogPid))
	flagLogJS      = flag.Bool("log-js", false, fmt.Sprintf("enable jobserver messages logging (%s=1)", EnvLogJS))

	LogMutex     sync.Mutex
	KeyEraseLine string
)

func init() {
	var b bytes.Buffer
	t := term.NewTerminal(&b, "")
	CDebug = string(t.Escape.Yellow)
	CRedo = string(t.Escape.Green)
	CWait = string(t.Escape.Blue)
	CLock = string(t.Escape.Cyan)
	CErr = string(t.Escape.Red)
	CWarn = string(t.Escape.Magenta)
	CJS = string(t.Escape.White)
	CReset = string(t.Escape.Reset)
	KeyEraseLine = fmt.Sprintf("%s[K", CReset[0:1])
}

func erasedStatus(s, end string) string {
	if NoProgress {
		return s + end
	}
	return s + KeyEraseLine + end
}

func trace(level, format string, args ...interface{}) {
	var p string
	if MyPid != 0 {
		p = fmt.Sprintf("[%d] ", MyPid)
	}
	switch level {
	case CNone:
		p = erasedStatus(StderrPrefix+p+fmt.Sprintf(format, args...), "\n")
		LogMutex.Lock()
		os.Stderr.WriteString(p)
		LogMutex.Unlock()
		return
	case CDebug:
		if !Debug {
			return
		}
		p += "dbg  "
	case CWait:
		if !(LogWait || Debug) {
			return
		}
		p += "wait "
	case CRedo:
		if NoProgress {
			return
		}
		p += "redo "
	case CLock:
		if !(LogLock || Debug) {
			return
		}
		p += "lock "
	case CJS:
		if !(LogJS || Debug) {
			return
		}
		p += "js   "
	case CErr:
		p += "err  "
	case CWarn:
		p += "warn "
	}
	msg := fmt.Sprintf(format, args...)
	msg = StderrPrefix + colourize(level, p+strings.Repeat(". ", Level)+msg)
	msg = erasedStatus(msg, "\n")
	LogMutex.Lock()
	os.Stderr.WriteString(msg)
	LogMutex.Unlock()
}

func colourize(colour, s string) string {
	if NoColor {
		return s
	}
	return colour + s + CReset
}
